@@ -9,25 +9,25 @@ import traceback
 import re
 import random
 import base64
+import html as html_decode
 
 import xlrd
 import xlwt
+from lxml import etree
 from xlutils.copy import copy
 from requests_html import HTMLSession
 
+Session = HTMLSession()
+"""
+爬虫请求模块，HTMLSession提供了Xpath方法，方便直接进行解析
+Crawler request module, HTMLSession provides Xpath method, convenient for parsing directly
 
-def Session():
-    """
-    爬虫请求模块，HTMLSession提供了Xpath方法，方便直接进行解析
-    Crawler request module, HTMLSession provides Xpath method, convenient for parsing directly
-
-    for example,
-    response = jrbox.Session.get(url, headers, cookies, params)
-    for div in response.html.xpath('.//div'):
-        title = div.xpath('*******')
-    :return: requests_html.HTMLSession的实例化方法
-    """
-    return HTMLSession()
+for example,
+response = jrbox.Session.get(url, headers, cookies, params)
+for div in response.html.xpath('.//div'):
+    title = div.xpath('*******')
+:return: requests_html.HTMLSession的实例化方法
+"""
 
 
 def test(data):
@@ -154,25 +154,19 @@ def SaveExcel(filename, data, Excel_head):
         print('异常:', data)
 
 
-def html_clean(text):
-    """
-    传入文本  -->  输出清除HTML标签后的文本
-    :param text: Type == str
-    :return: new text
-    """
-    text = re.sub(r'<[^>]+>', '', text)
-    return text
+html_clean = lambda text: re.sub(r'<[^>]+>', '', text)
+"""
+传入文本  -->  输出清除HTML标签后的文本
+:param text: Type == str
+:return: new text
+"""
 
-
-def filename_clean(filename):
-    """
-    传入文本 --> 输出清除文件名非法字符后的文本
-    :param filename: Type == str
-    :return: new name
-    """
-    replace_str = r"[\/\\\:\*\?\"\<\>\|]"  # '/ \ : * ? " < > |'
-    new_name = re.sub(replace_str, "_", filename)  # 替换为下划线
-    return new_name
+filename_clean = lambda filename: re.sub(r"[\/\\\:\*\?\"\<\>\|]", "_", filename)
+"""
+传入文本 --> 输出清除文件名非法字符后的文本
+:param filename: Type == str
+:return: new name
+"""
 
 
 def SaveExcels(file_name, data, sheet, Excel_head):
@@ -359,7 +353,7 @@ def Fanyi(keyword, From, To):
         }
         try:
             response = Session().post(url=url, headers=headers, data=data,
-                                     cookies=cookies_dict).json()["translateResult"][0][0]["tgt"]
+                                      cookies=cookies_dict).json()["translateResult"][0][0]["tgt"]
             return response
             # print('翻译结果为:', response["translateResult"][0][0]["tgt"])
 
@@ -391,7 +385,7 @@ def Fanyi(keyword, From, To):
             }
 
             response = Session().post(url=url, headers=headers, data=data,
-                                     cookies=cookies_dict).json()
+                                      cookies=cookies_dict).json()
             keyword = response["translateResult"][0][0]["tgt"]
 
             lts = str(int(time.time() * 1000))
@@ -415,7 +409,7 @@ def Fanyi(keyword, From, To):
             }
 
             response = Session().post(url=url, headers=headers, data=data,
-                                     cookies=cookies_dict).json()["translateResult"][0][0]["tgt"]
+                                      cookies=cookies_dict).json()["translateResult"][0][0]["tgt"]
             # print('翻译结果为:', response["translateResult"][0][0]["tgt"])
             return response
         except:
@@ -423,22 +417,17 @@ def Fanyi(keyword, From, To):
             return text
 
 
-def text_to_base64(text):
-    """
-    :param text: Type == str
-    :return: Type == str
-    """
-    to_b64 = base64.b64encode(text.encode('utf-8')).decode("utf-8")
-    return to_b64
+text_to_base64 = lambda text: base64.b64encode(text.encode('utf-8')).decode("utf-8")
+"""
+:param text: Type == str
+:return: Type == str
+"""
 
-
-def base64_to_text(text):
-    """
-    :param text: Type == str
-    :return: Type == str
-    """
-    to_text = base64.b64decode(text.encode("utf-8")).decode("utf-8")
-    return to_text
+base64_to_text = lambda text: base64.b64decode(text.encode("utf-8")).decode("utf-8")
+"""
+:param text: Type == str
+:return: Type == str
+"""
 
 
 def mkdir(dir_name):
@@ -457,12 +446,17 @@ def mkdir(dir_name):
         print(f'路径存在:{os_mkdir_path}')
 
 
-def video_pojie(url):
-    """
-    支持众多主流视频站点:API拼接网页链接，访问即可
-    :param url: Type == str
-    :return: Type == str
-    """
-    Api_url = 'http://okjx.cc/?url=' + url
-    return Api_url
+video_pojie = lambda url: 'http://okjx.cc/?url=' + url
+"""
+支持众多主流视频站点:API拼接网页链接，访问即可
+:param url: Type == str
+:return: Type == str
+"""
 
+html_node_text = lambda HTML, XPATH: html_decode.unescape(
+    html_clean(str(etree.tostring(etree.HTML(HTML).xpath(XPATH)[0])))).lstrip("b'").rstrip("'")
+"""
+HTML: Web site source code
+XPATH: Node XPATH Syntax
+retur: Node, the front page display text data
+"""
